From: Tanjuate Brunostar <tanjubrunostar0@gmail.com>
To: gregkh@linuxfoundation.org
Cc: linux-staging@lists.linux.dev, linux-kernel@vger.kernel.org,
outreachy@lists.linux.dev,
Tanjuate Brunostar <tanjubrunostar0@gmail.com>
Subject: [PATCH 10/17] staging: vt6655: changed variable name: s_vGenerateTxParameter
Date: Tue, 25 Oct 2022 23:37:06 +0000 [thread overview]
Message-ID: <1663fb051fe1a25189bb578e1e6bcde7f9ad39d4.1666740522.git.tanjubrunostar0@gmail.com> (raw)
In-Reply-To: <cover.1666740522.git.tanjubrunostar0@gmail.com>
change variable names s_vGenerateTxParameter to meet the
linux coding standard, as it says to avoid using camelCase naming
style. Cought by checkpatch
Signed-off-by: Tanjuate Brunostar <tanjubrunostar0@gmail.com>
---
drivers/staging/vt6655/rxtx.c | 63 ++++++++++++++++++-----------------
1 file changed, 32 insertions(+), 31 deletions(-)
diff --git a/drivers/staging/vt6655/rxtx.c b/drivers/staging/vt6655/rxtx.c
index 3d28cbfec618..fa11677ce119 100644
--- a/drivers/staging/vt6655/rxtx.c
+++ b/drivers/staging/vt6655/rxtx.c
@@ -10,7 +10,7 @@
* Date: May 20, 2003
*
* Functions:
* s_vGenerateTxParameter - Generate tx dma required parameter.
* vGenerateMACHeader - Translate 802.3 to 802.11 header
* cbGetFragCount - Calculate fragment number count
* csBeacon_xmit - beacon tx function
@@ -95,23 +95,24 @@ static void s_v_fill_rts_head(struct vnt_private *p_device,
unsigned short wCurrentRate,
unsigned char by_fb_option);
-static void s_vGenerateTxParameter(struct vnt_private *p_device,
- unsigned char by_pkt_type,
- struct vnt_tx_fifo_head *,
- void *pvRrvTime,
- void *pv_rts,
- void *pvCTS,
- unsigned int cbFrameSize,
- bool bNeedACK,
- unsigned int uDMAIdx,
- void *psEthHeader,
- unsigned short wCurrentRate);
-
-static unsigned int
-s_cbFillTxBufHead(struct vnt_private *p_device, unsigned char by_pkt_type,
- unsigned char *pbyTxBufferAddr,
- unsigned int uDMAIdx, struct vnt_tx_desc *pHeadTD,
- unsigned int uNodeIndex);
+static void s_vgenerate_tx_parameter(struct vnt_private *p_device,
+ unsigned char by_pkt_type,
+ struct vnt_tx_fifo_head *,
+ void *pvRrvTime,
+ void *pv_rts,
+ void *pvCTS,
+ unsigned int cbFrameSize,
+ bool bNeedACK,
+ unsigned int uDMAIdx,
+ void *psEthHeader,
+ unsigned short wCurrentRate);
+
+static unsigned int s_cbFillTxBufHead(struct vnt_private *p_device,
+ unsigned char by_pkt_type,
+ unsigned char *pbyTxBufferAddr,
+ unsigned int uDMAIdx,
+ struct vnt_tx_desc *pHeadTD,
+ unsigned int uNodeIndex);
static __le16 s_uFillDataHead(struct vnt_private *p_device,
unsigned char by_pkt_type,
@@ -936,17 +937,17 @@ static void s_vFillCTSHead(struct vnt_private *p_device,
-
* unsigned int cbFrameSize, Hdr+Payload+FCS
*/
-static void s_vGenerateTxParameter(struct vnt_private *p_device,
- unsigned char by_pkt_type,
- struct vnt_tx_fifo_head *tx_buffer_head,
- void *pvRrvTime,
- void *pv_rts,
- void *pvCTS,
- unsigned int cbFrameSize,
- bool bNeedACK,
- unsigned int uDMAIdx,
- void *psEthHeader,
- unsigned short wCurrentRate)
+static void s_vgenerate_tx_parameter(struct vnt_private *p_device,
+ unsigned char by_pkt_type,
+ struct vnt_tx_fifo_head *tx_buffer_head,
+ void *pvRrvTime,
+ void *pv_rts,
+ void *pvCTS,
+ unsigned int cbFrameSize,
+ bool bNeedACK,
+ unsigned int uDMAIdx,
+ void *psEthHeader,
+ unsigned short wCurrentRate)
{
u16 fifo_ctl = le16_to_cpu(tx_buffer_head->fifo_ctl);
bool b_dis_crc = false;
@@ -1223,8 +1224,8 @@ static unsigned int s_cbFillTxBufHead(struct vnt_private *p_device,
memset((void *)(pbyTxBufferAddr + wTxBufSize), 0, (cbHeaderLength - wTxBufSize));
/* Fill FIFO,RrvTime,RTS,and CTS */
- s_vGenerateTxParameter(p_device, by_pkt_type, tx_buffer_head, pvRrvTime, pv_rts, pvCTS,
- cbFrameSize, bNeedACK, uDMAIdx, hdr, p_device->wCurrentRate);
+ s_vgenerate_tx_parameter(p_device, by_pkt_type, tx_buffer_head, pvRrvTime, pv_rts, pvCTS,
+ cbFrameSize, bNeedACK, uDMAIdx, hdr, p_device->wCurrentRate);
/* Fill DataHead */
uDuration = s_uFillDataHead(p_device, by_pkt_type, pvTxDataHd, cbFrameSize, uDMAIdx,
bNeedACK, 0, 0, uMACfragNum, by_fb_option,
@@ -10,7 +10,7 @@
*
* Functions:
- * s_vGenerateTxParameter - Generate tx dma required parameter.
+ * s_vgenerate_tx_parameter - Generate tx dma required parameter.
* vGenerateMACHeader - Translate 802.3 to 802.11 header
* cbGetFragCount - Calculate fragment number count
--
2.34.1
next prev parent reply other threads:[~2022-10-25 23:39 UTC|newest]
Thread overview: 25+ messages / expand[flat|nested] mbox.gz Atom feed top
2022-10-25 23:36 [PATCH 00/17] staging: vt6655: a series of checkpatch fixes on the file: rxtx.c Tanjuate Brunostar
2022-10-25 23:36 ` [PATCH 01/17] staging: vt6655: changed variable names: wFB_Opt0 Tanjuate Brunostar
2022-10-26 2:46 ` Philipp Hortmann
2022-10-26 3:24 ` Philipp Hortmann
2022-10-25 23:36 ` [PATCH 02/17] staging: vt6655: changed variable names: s_vFillRTSHead Tanjuate Brunostar
2022-10-26 2:56 ` Philipp Hortmann
2022-10-26 13:52 ` Greg KH
2022-10-25 23:36 ` [PATCH 03/17] staging: vt6655: changed variable name: pDevice Tanjuate Brunostar
2022-10-26 3:03 ` Philipp Hortmann
2022-10-25 23:37 ` [PATCH 04/17] staging: vt6655: changed variable name: byPktType Tanjuate Brunostar
2022-10-25 23:37 ` [PATCH 05/17] staging: vt6655: changed variable name: pvRTS Tanjuate Brunostar
2022-10-26 13:51 ` Greg KH
2022-10-27 6:12 ` Tanju Brunostar
2022-10-25 23:37 ` [PATCH 06/17] staging: vt6655: changed variable name: cbFrameLength Tanjuate Brunostar
2022-10-25 23:37 ` [PATCH 07/17] staging: vt6655: changed variable name: b_need_ack Tanjuate Brunostar
2022-10-25 23:37 ` [PATCH 08/17] staging: vt6655: changed variable name: bDisCRC Tanjuate Brunostar
2022-10-25 23:37 ` [PATCH 09/17] staging: vt6655: changed variable name: byFBOption Tanjuate Brunostar
2022-10-25 23:37 ` Tanjuate Brunostar [this message]
2022-10-25 23:37 ` [PATCH 11/17] staging: vt6655: changed variable name: pvRrvTime Tanjuate Brunostar
2022-10-25 23:37 ` [PATCH 12/17] staging: vt6655: changed variable name: cbFrameSize Tanjuate Brunostar
2022-10-25 23:37 ` [PATCH 13/17] staging: vt6655: changed variable name: bNeedACK Tanjuate Brunostar
2022-10-25 23:37 ` [PATCH 14/17] staging: vt6655: changed variable name: uDMAIdx Tanjuate Brunostar
2022-10-25 23:37 ` [PATCH 15/17] staging: vt6655: changed variable name: psEthHeader Tanjuate Brunostar
2022-10-25 23:37 ` [PATCH 16/17] staging: vt6655: changed variable name: s_cbFillTxBufHead Tanjuate Brunostar
2022-10-25 23:37 ` [PATCH 17/17] staging: vt6655: changed variable name: pbyTxBufferAddr Tanjuate Brunostar
Reply instructions:
You may reply publicly to this message via plain-text email
using any one of the following methods:
* Save the following mbox file, import it into your mail client,
and reply-to-all from there: mbox
Avoid top-posting and favor interleaved quoting:
https://en.wikipedia.org/wiki/Posting_style#Interleaved_style
* Reply using the --to, --cc, and --in-reply-to
switches of git-send-email(1):
git send-email \
--in-reply-to=1663fb051fe1a25189bb578e1e6bcde7f9ad39d4.1666740522.git.tanjubrunostar0@gmail.com \
--to=tanjubrunostar0@gmail.com \
--cc=gregkh@linuxfoundation.org \
--cc=linux-kernel@vger.kernel.org \
--cc=linux-staging@lists.linux.dev \
--cc=outreachy@lists.linux.dev \
/path/to/YOUR_REPLY
https://kernel.org/pub/software/scm/git/docs/git-send-email.html
* If your mail client supports setting the In-Reply-To header
via mailto: links, try the mailto: link
Be sure your reply has a Subject: header at the top and a blank line
before the message body.
This is a public inbox, see mirroring instructions
for how to clone and mirror all data and code used for this inbox
all inboxes | Powered by JetHome®